@@ -4,7 +4,7 @@ DAL Exceptions.
 
 __all__ = [
     "DALAccessError", "DALProtocolError", "DALFormatError", "DALServiceError",
-    "DALQueryError"]
+    "DALQueryError", "DALOverflowWarning"]
 
 import re
 
@@ -176,11 +176,21 @@ class DALServiceError(DALProtocolError):
         for the given exception that represents the underlying cause.
         """
         if isinstance(exc, requests.exceptions.RequestException):
-            message = str(exc)
             try:
-                code = exc.response.status_code
+                response = exc.response
             except AttributeError:
-                code = 0
+                response = None
+            code = 0
+            message = str(exc)
+
+            # if there is a response, refine the error message
+            if response is not None:
+                code = response.status_code
+                content_type = response.headers.get('content-type', None)
+                if content_type and 'text/plain' in content_type:
+                    message = '{} for {}'.format(response.text, url)
+
+            # TODO votable handling
 
             return DALServiceError(message, code, exc, url)
         elif isinstance(exc, Exception):
@@ -232,3 +242,7 @@ class DALQueryError(DALAccessError):
 
 class PyvoUserWarning(AstropyUserWarning):
     pass
+
+
+class DALOverflowWarning(UserWarning):
+    pass
