@@ -26,10 +26,8 @@ import os
 import shutil
 import re
 import requests
-try:
-    from collections.abc import Mapping
-except ImportError:
-    from collections import Mapping
+from collections.abc import Mapping
+
 import collections
 
 from warnings import warn
@@ -40,7 +38,8 @@ from astropy.io.votable.ucd import parse_ucd
 from astropy.utils.exceptions import AstropyDeprecationWarning
 
 from .mimetype import mime_object_maker
-from .exceptions import (DALFormatError, DALServiceError, DALQueryError)
+from .exceptions import (DALFormatError, DALServiceError, DALQueryError,
+                         DALOverflowWarning)
 
 from .. import samp
 
@@ -319,6 +318,10 @@ class DALResults:
         if self._status[0].lower() not in ("ok", "overflow"):
             raise DALQueryError(self._status[1], self._status[0], url)
 
+        if self._status[0].lower() == "overflow":
+            warn("Partial result set. Potential causes MAXREC, async storage space, etc.",
+                 category=DALOverflowWarning)
+
         self._resultstable = self._findresultstable(votable)
         if not self._resultstable:
             raise DALFormatError(
@@ -376,9 +379,13 @@ class DALResults:
 
     def _findstatusinfo(self, infos):
         # this can be overridden to specialize for a particular DAL protocol
+        status = None
+        # return the last status to catch potential overflow or error sent
+        # after the results.
         for info in infos:
             if info.name.lower() == 'query_status':
-                return info
+                status = info
+        return status
 
     def _findinfos(self, votable):
         # this can be overridden to specialize for a particular DAL protocol
@@ -428,7 +435,7 @@ class DALResults:
     def table(self):
         warn(AstropyDeprecationWarning(
             'Using the table property is deprecated. '
-            'Please use se to_table() instead.'
+            'Please use the to_table() instead.'
         ))
         return self.to_table()
 
@@ -706,8 +713,8 @@ class Record(Mapping):
         for fieldname in self._results.fieldnames:
             field = self._results.getdesc(fieldname)
             if (field.utype and "access.reference" in field.utype.lower()) or (
-                    field.ucd and "meta.dataset" in field.ucd and
-                    "meta.ref.url" in field.ucd
+                    field.ucd and "meta.dataset" in field.ucd
+                    and "meta.ref.url" in field.ucd
             ):
                 out = self[fieldname]
                 if isinstance(out, bytes):
@@ -717,7 +724,7 @@ class Record(Mapping):
 
     def getdataobj(self):
         """
-        return the appropiate data object suitable for the data content behind
+        return the appropriate data object suitable for the data content behind
         this record.
         """
         return mime_object_maker(self.getdataurl(), self.getdataformat())
@@ -762,8 +769,11 @@ class Record(Mapping):
             response = self._session.get(url, stream=True, timeout=timeout)
         else:
             response = self._session.get(url, stream=True)
+        try:
+            response.raise_for_status()
+        except requests.RequestException as ex:
+            raise DALServiceError.from_except(ex, url)
 
-        response.raise_for_status()
         return response.raw
 
     def cachedataset(self, filename=None, dir=".", timeout=None, bufsize=None):
