@@ -11,7 +11,7 @@ endpoint.
 """
 
 from astropy import units as u
-from astropy import time
+from astropy.time import Time
 
 from .query import DALResults, DALQuery, DALService, Record
 from .adhoc import DatalinkResultsMixin, AxisParamMixin, SodaRecordMixin,\
@@ -169,9 +169,9 @@ class SIAService(DALService, AvailabilityMixin, CapabilityMixin):
             if cap.standardid.lower() == SIA2_STANDARD_ID.lower():
                 for interface in cap.interfaces:
                     if interface.accessurls and \
-                            not (len(interface.securitymethods) == 1 and
-                                 interface.securitymethods[0].standardid ==
-                                 'ivo://ivoa.net/sso#BasicAA'):
+                            not (len(interface.securitymethods) == 1
+                                 and interface.securitymethods[0].standardid
+                                 == 'ivo://ivoa.net/sso#BasicAA'):
                         self.query_ep = interface.accessurls[0].content
                         break
 
@@ -457,18 +457,13 @@ class SIAResults(DatalinkResultsMixin, DALResults):
     The list of matching images resulting from an image (SIA) query.
     Each record contains a set of metadata that describes an available
     image matching the query constraints.  The number of records in
-    the results is available via the :py:attr:`nrecs` attribute or by
-    passing it to the Python built-in ``len()`` function.
+    the results is available by passing it to the Python built-in ``len()`` function.
 
     This class supports iterable semantics; thus,
     individual records (in the form of
     :py:class:`~pyvo.dal.sia2.ObsCoreRecord` instances) are typically
     accessed by iterating over an ``SIAResults`` instance.
 
-    >>> results = pyvo.imagesearch(url, pos=[12.24, -13.1], size=0.1)
-    >>> for image in results:
-    ...     print("{0}: {1}".format(image.title, title.getdataurl()))
-
     Alternatively, records can be accessed randomly via
     :py:meth:`getrecord` or through a Python Database API (v2)
     Cursor (via :py:meth:`~pyvo.dal.query.DALResults.cursor`).
@@ -487,7 +482,7 @@ class SIAResults(DatalinkResultsMixin, DALResults):
     as an Astropy :py:class:`~astropy.table.table.Table` via the
     following conversion:
 
-    >>> table = results.votable.to_table()
+    ``table = results.votable.to_table()``
 
     ``SIAResults`` supports the array item operator ``[...]`` in a
     read-only context.  When the argument is numerical, the result
@@ -627,7 +622,7 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         Date when the dataset was created
         """
         cd = self.get('obs_create_date', default=None)
-        return cd if not cd else time.Time(cd)
+        return cd if not cd else Time(cd)
 
     @property
     def obs_creator_name(self):
@@ -650,7 +645,7 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         Observation release date
         """
         rt = self.get('obs_release_date', default=None, decode=True)
-        return rt if not rt else time.Time(rt)
+        return rt if not rt else Time(rt)
 
     @property
     def obs_publisher_did(self):
@@ -716,7 +711,7 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         required. Provision of dataset size estimates is important whenever it
         is possible that datasets can be very large.
         """
-        return self.get('access_estsize')*1000*u.byte
+        return self.get('access_estsize') * 1000 * u.byte
 
     #           SPATIAL CHARACTERISATION
     @property
@@ -724,14 +719,14 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         """
         ICRS Right Ascension of the center of the observation
         """
-        return self.get('s_ra')*u.deg
+        return self.get('s_ra') * u.deg
 
     @property
     def s_dec(self):
         """
         CRS Declination of the center of the observation
         """
-        return self.get('s_dec')*u.deg
+        return self.get('s_dec') * u.deg
 
     @property
     def s_fov(self):
@@ -748,7 +743,7 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         data product. The spatial coverage of a data product can be more
         precisely specified using the region attribute.
         """
-        return self.get('s_fov')*u.deg
+        return self.get('s_fov') * u.deg
 
     @property
     def s_region(self):
@@ -777,7 +772,7 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         characterisation may be necessary to fully specify the spatial
         characteristics of the data.
         """
-        return self.get('s_resolution')*u.arcsec
+        return self.get('s_resolution') * u.arcsec
 
     @property
     def s_xel1(self):
@@ -813,7 +808,7 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         Resolution min value on spatial axis (FHWM of PSF)
         """
         rmin = self.get('s_resolution_min', default=None)
-        return rmin if not rmin else rmin*u.arcsec
+        return rmin if not rmin else rmin * u.arcsec
 
     @property
     def s_resolution_max(self):
@@ -872,7 +867,7 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         products result of the combination of multiple frames, min time must
         be the minimum of the start times
         """
-        return time.Time(self.get('t_min'), format='mjd')
+        return Time(self.get('t_min'), format='mjd')
 
     @property
     def t_max(self):
@@ -881,7 +876,7 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         products result of the combination of multiple frames, t_max must
         be the maximum of the stop times
         """
-        return time.Time(self.get('t_min'), format='mjd')
+        return Time(self.get('t_min'), format='mjd')
 
     @property
     def t_exptime(self):
@@ -902,14 +897,14 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         often adjusted to achieve similar signal to noise ratio for different
         targets.
         """
-        return self.get('t_exptime')*u.second
+        return self.get('t_exptime') * u.second
 
     @property
     def t_resolution(self):
         """
         Estimated or average value of the temporal resolution.
         """
-        return self.get('t_resolution')*u.second
+        return self.get('t_resolution') * u.second
 
     @property
     def t_calib_status(self):
@@ -926,7 +921,7 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         Time coord statistical error on the time measurements in seconds
         """
         ter = self.get('t_stat_error', default=None)
-        return ter if not ter else ter*u.second
+        return ter if not ter else ter * u.second
 
     #           SPECTRAL CHARACTERISATION
     @property
@@ -965,14 +960,14 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         """
         Minimum of the spectral interval covered by the observation
         """
-        return self.get('em_min')*u.meter
+        return self.get('em_min') * u.meter
 
     @property
     def em_max(self):
         """
         Maximum of the spectral interval covered by the observation
         """
-        return self.get('em_max')*u.meter
+        return self.get('em_max') * u.meter
 
     @property
     def em_res_power(self):
@@ -1005,7 +1000,7 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         power is preferable due to the LSF variation along the spectral axis.
         """
         if 'em_resolution' in self.keys():
-            return self.get('em_resolution')*u.meter
+            return self.get('em_resolution') * u.meter
         return None
 
     @property
@@ -1014,7 +1009,7 @@ class ObsCoreRecord(SodaRecordMixin, DatalinkRecordMixin, Record,
         Spectral coord statistical error (accuracy along the spectral axis)
         """
         if 'em_stat_error' in self.keys():
-            return self.get('em_stat_error')*u.meter
+            return self.get('em_stat_error') * u.meter
         return None
 
     #           OBSERVABLE AXIS
