@@ -29,14 +29,10 @@ URL.
 The SSAService class can represent a specific service available at a URL
 endpoint.
 """
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals)
-
 import re
 
 from pyvo.io.vosi.vodataservice import TableParam
 
-import six
 from astropy.coordinates import SkyCoord
 from astropy.time import Time
 from astropy.units import Quantity, Unit
@@ -54,7 +50,7 @@ __all__ = ["search", "SSAService", "SSAQuery", "SSAResults", "SSARecord"]
 
 
 def search(
-        baseurl, pos=None, diameter=None, band=None, time=None, format='all',
+        baseurl, pos=None, diameter=None, band=None, time=None, format=None,
         **keywords):
     """
     submit a simple SSA query that requests spectra overlapping a given region
@@ -114,7 +110,7 @@ class SSAService(DALService):
     a representation of an SSA service
     """
 
-    def __init__(self, baseurl):
+    def __init__(self, baseurl, session=None):
         """
         instantiate an SSA service
 
@@ -123,7 +119,7 @@ class SSAService(DALService):
         baseurl : str
            the base URL for submitting search queries to the service.
         """
-        super(SSAService, self).__init__(baseurl)
+        super().__init__(baseurl, session=session)
 
     def _get_metadata(self):
         """
@@ -165,7 +161,7 @@ class SSAService(DALService):
             return []
 
     def search(
-            self, pos=None, diameter=None, band=None, time=None, format='all',
+            self, pos=None, diameter=None, band=None, time=None, format=None,
             **keywords):
         """
         submit a SSA query to this service with the given constraints.
@@ -262,7 +258,7 @@ class SSAService(DALService):
         """
         return SSAQuery(
             self.baseurl, pos, diameter, band, time, format, request,
-            **keywords)
+            session=self._session, **keywords)
 
     def describe(self):
         print(self.description)
@@ -314,7 +310,7 @@ class SSAQuery(DALQuery):
 
     def __init__(
             self, baseurl, pos=None, diameter=None, band=None, time=None,
-            format=None, request="queryData", **keywords):
+            format=None, request="queryData", session=None, **keywords):
         """
         initialize the query object with a baseurl and the given parameters
 
@@ -340,27 +336,29 @@ class SSAQuery(DALQuery):
            graphical images (e.g. jpeg, png, gif; not FITS);
            "metadata" indicates that no images should be
            returned--only an empty table with complete metadata.
+        session : object
+           optional session to use for network requests
         **keywords :
            additional case insensitive parameters can be given via arbitrary
            case insensitive keyword arguments. Where there is overlap
            with the parameters set by the other arguments to
            this function, these keywords will override.
         """
-        super(SSAQuery, self).__init__(baseurl)
+        super().__init__(baseurl, session=session)
 
-        if pos:
+        if pos is not None:
             self.pos = pos
 
-        if diameter:
+        if diameter is not None:
             self.diameter = diameter
 
-        if band:
+        if band is not None:
             self.band = band
 
-        if time:
+        if time is not None:
             self.time = time
 
-        if format:
+        if format is not None:
             self.format = format
 
         self.request = request
@@ -505,8 +503,15 @@ class SSAQuery(DALQuery):
             except TypeError:
                 raise valerr
 
+        # It seems astropy either has seconds and microseconds (the date_hms
+        # subformat) or no seconds at all (the date_hm subformat).  SSAP
+        # probably doesn't allow microseconds.  Rather than fix this
+        # via a new astropy subformat, let's get by with local string
+        # operations.
+        literals = time.to_value('isot')
         self["TIME"] = "{start}/{end}".format(
-            start=time.isot[0], end=time.isot[1])
+            start=literals[0].split(".")[0],
+            end=literals[1].split(".")[0])
 
     @time.deleter
     def time(self):
@@ -528,7 +533,7 @@ class SSAQuery(DALQuery):
     def format(self, val):
         setattr(self, "_format", val)
 
-        if type(val) in (six.text_type, six.binary_type):
+        if type(val) in (str, bytes):
             val = [val]
 
         self["FORMAT"] = ",".join(val)
@@ -569,7 +574,7 @@ class SSAQuery(DALQuery):
         DALFormatError
            for errors parsing the VOTable response
         """
-        return SSAResults(self.execute_votable(), url=self.queryurl)
+        return SSAResults(self.execute_votable(), url=self.queryurl, session=self._session)
 
 
 class SSAResults(DatalinkResultsMixin, DALResults):
@@ -584,10 +589,6 @@ class SSAResults(DatalinkResultsMixin, DALResults):
     :py:class:`~pyvo.dal.ssa.SSARecord` instances) are typically
     accessed by iterating over an ``SSAResults`` instance.
 
-    >>> results = pyvo.spectrumsearch(url, pos=[12.24, -13.1], diameter=0.2)
-    >>> for spec in results:
-    ...     print("{0}: {1}".format(spec.title, spec.getdataurl()))
-
     Alternatively, records can be accessed randomly via
     :py:meth:`getrecord` or through a Python Database API (v2)
     Cursor (via :py:meth:`~pyvo.dal.query.DALResults.cursor`).
@@ -606,7 +607,7 @@ class SSAResults(DatalinkResultsMixin, DALResults):
     as an Astropy :py:class:`~astropy.table.table.Table` via the
     following conversion:
 
-    >>> table = results.votable.to_table()
+    ``table = results.votable.to_table()``
 
     ``SSAResults`` supports the array item operator ``[...]`` in a
     read-only context.  When the argument is numerical, the result
@@ -646,7 +647,7 @@ class SSAResults(DatalinkResultsMixin, DALResults):
         --------
         Record
         """
-        return SSARecord(self, index)
+        return SSARecord(self, index, session=self._session)
 
 
 class SSARecord(SodaRecordMixin, DatalinkRecordMixin, Record):
@@ -730,7 +731,7 @@ class SSARecord(SodaRecordMixin, DatalinkRecordMixin, Record):
         to retrieve the dataset described by this record.  None is returned
         if no such column exists.
         """
-        dataurl = super(SSARecord, self).getdataurl()
+        dataurl = super().getdataurl()
         if dataurl is None:
             return self.acref
         else:
@@ -745,7 +746,7 @@ class SSARecord(SodaRecordMixin, DatalinkRecordMixin, Record):
         ``make_dataset_filename()``.
         """
         out = self.title
-        if type(out) == six.binary_type:
+        if type(out) == bytes:
             out = out.decode('utf-8')
 
         if not out:
