@@ -3,6 +3,7 @@
 """
 Tests for pyvo.io.vosi
 """
+import io
 from operator import eq as equals
 
 import pytest
@@ -15,10 +16,10 @@ from pyvo.io.vosi.exceptions import W06
 from astropy.utils.data import get_pkg_data_filename
 
 
-@pytest.fixture()
-def parsed_caps():
+@pytest.fixture(name='parsed_caps')
+def _parsed_caps():
     return vosi.parse_capabilities(get_pkg_data_filename(
-            "data/capabilities.xml"))
+        "data/capabilities.xml"))
 
 
 @pytest.mark.usefixtures("parsed_caps")
@@ -162,13 +163,50 @@ class TestInterface:
         assert len(parsed_caps[3].interfaces[0].mirrorurls) == 2
 
     def test_mirrors_have_titles(self, parsed_caps):
-        assert [m.title for m in parsed_caps[3].interfaces[0].mirrorurls
-            ] == ["https version", "Paris mirror"]
+        assert ([m.title for m in parsed_caps[3].interfaces[0].mirrorurls]
+                == ["https version", "Paris mirror"])
 
     def test_mirrors_have_urls(self, parsed_caps):
-        assert [m.content for m in parsed_caps[3].interfaces[0].mirrorurls
-            ] == ['https://example.org/tap', 'https://paris.example.org/tap']
+        assert ([m.content for m in parsed_caps[3].interfaces[0].mirrorurls]
+                == ['https://example.org/tap', 'https://paris.example.org/tap'])
 
     def test_testquerystring_parsed(self, parsed_caps):
         assert (parsed_caps[3].interfaces[0].testquerystring.content
-            == 'QUERY=SELECT%20*%20FROM%20tap_schema.tables&LANG=ADQL')
+                == 'QUERY=SELECT%20*%20FROM%20tap_schema.tables&LANG=ADQL')
+
+
+@pytest.fixture(name='cap_with_free_prefix')
+def _cap_with_free_prefix(recwarn):
+    caps = vosi.parse_capabilities(io.BytesIO(b"""
+<ns2:capabilities xmlns:ns2="http://www.ivoa.net/xml/VOSICapabilities/v1.0">
+  <capability
+    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+    xmlns:ns4="http://www.ivoa.net/xml/TAPRegExt/v1.0"
+    xsi:type="ns4:TableAccess"
+    standardID="ivo://ivoa.net/std/TAP">
+    <interface xmlns:ns5="http://www.ivoa.net/xml/VODataService/v1.1"
+        xsi:type="ns5:ParamHTTP" version="1.1" role="std">
+      <accessURL use="base">https://archive.eso.org/tap_obs</accessURL>
+    </interface>
+    <dataModel ivo-id="ivo://ivoa.net/std/ObsCore#core-1.1">ObsCore-1.1</dataModel>
+    <outputFormat/>
+    <language>
+      <name>ADQL</name>
+      <version ivo-id="ivo://ivoa.net/std/ADQL#v2.0">2.0</version>
+      <description>ADQL-2.0</description>
+    </language>
+  </capability>
+</ns2:capabilities>"""))
+    return recwarn, caps
+
+
+# this is a test for when people ignore the canonical prefixes for
+# registry documents.
+class TestFreePrefixes:
+    def test_parses_without_warning(self, cap_with_free_prefix):
+        warnings, _ = cap_with_free_prefix
+        assert len(warnings) == 0
+
+    def test_parses_as_tapregext(self, cap_with_free_prefix):
+        _, cap = cap_with_free_prefix
+        assert isinstance(cap[0], tr.TableAccess)
